==> kunlun-server-0.9.1.tgz: kunlun-server-0.9.1/include/postgresql/server/nodes/print.h <==
/*-------------------------------------------------------------------------
 *
 * print.h
 *	  definitions for nodes/print.c
 *
 *
 * Portions Copyright (c) 1996-2018, PostgreSQL Global Development Group
 * Portions Copyright (c) 1994, Regents of the University of California
 *
 * src/include/nodes/print.h
 *
 *-------------------------------------------------------------------------
 */
#ifndef PRINT_H
#define PRINT_H

#include "executor/tuptable.h"
#include "lib/stringinfo.h"
#include "nodes/params.h"

#define nodeDisplay(x)		pprint(x)

/*
 * Print the PlaceHolderVar with newly generated alias if it is just a reference
 */
struct PlaceHolderVar;
typedef struct PhvAlias
{
	struct PlaceHolderVar *phv;
	char *alias;
} PhvAlias;

typedef struct RemotePrintExprContext
{
	const List *rtable;
	/*
	  All Params' 'paramid' indexes refer to this array.
	*/
	ParamExecData *rpec_param_exec_vals;
	ParamListInfo rpec_param_list_info;
	/*
	  If true, Param node will be treated as unsupported, otherwise
	  the qual containing the param will be serialized.
	*/
	bool ignore_param_quals;
	/*
	  True when currently traversing agg count() 's arg nodes.
	*/
	bool is_agg_count_args;
	bool has_aggref;
	int skip_n; // skip first N elements
	/*
	  How many values is the target expr serialized to. 1 for most exprs,
	  except a few like RowExpr.
	*/
	int num_vals;

	/* Placeholder vars that assigned aliases */
	List *phv_alias;
} RemotePrintExprContext;

extern void InitRemotePrintExprContext(RemotePrintExprContext *rpec, List*rtable);
extern void ResetRemotePrintExprContext(RemotePrintExprContext *rpec, bool b);
extern void print(const void *obj);
extern void pprint(const void *obj);
extern void elog_node_display(int lev, const char *title,
				  const void *obj, bool pretty);
extern char *format_node_dump(const char *dump);
extern char *pretty_format_node_dump(const char *dump);
extern void print_rt(const List *rtable);
extern void print_expr(const Node *expr, const List *rtable);
extern void print_pathkeys(const List *pathkeys, const List *rtable);
extern void print_tl(const List *tlist, const List *rtable);
extern void print_slot(TupleTableSlot *slot);
extern int snprint_expr(StringInfo buf, const Expr *expr, RemotePrintExprContext *rpec);
#endif							/* PRINT_H */

==> kunlun-server-0.9.2.tgz: kunlun-server-0.9.2/include/postgresql/server/nodes/print.h <==
/*-------------------------------------------------------------------------
 *
 * print.h
 *	  definitions for nodes/print.c
 *
 *
 * Portions Copyright (c) 1996-2018, PostgreSQL Global Development Group
 * Portions Copyright (c) 1994, Regents of the University of California
 *
 * src/include/nodes/print.h
 *
 *-------------------------------------------------------------------------
 */
#ifndef PRINT_H
#define PRINT_H

#include "executor/tuptable.h"
#include "lib/stringinfo.h"
#include "nodes/params.h"

#define nodeDisplay(x)		pprint(x)

/*
 * Print the PlaceHolderVar with newly generated alias if it is just a reference
 */
struct PlaceHolderVar;
typedef struct PhvAlias
{
	struct PlaceHolderVar *phv;
	char *alias;
} PhvAlias;

typedef struct VarAlias
{
	Var *var;
	char *alias;
} VarAlias;
/**
 * @brief Parameter information collected in snprint_expr
 */
typedef struct ParamPlaceholder
{
       Expr *param;
       /* The placeholder's location in printed sql */
       int location;
} ParamPlaceholder;

typedef struct RemotePrintExprContext
{
	EState *estate;
	const List *rtable;
	/*
	  All Params' 'paramid' indexes refer to this array.
	*/
	ParamExecData *rpec_param_exec_vals;
	ParamListInfo rpec_param_list_info;

	/* True if print param/unsafe func as '?' */
	bool make_prepare_stmt;
	/* Information abort the param (i.e. position in sql)*/
	List *param_placeholders;
	/* Information abort the unsafe function */
	List *unsafe_func_placeholder;

	/*
	  If true, param node will be executed if it does not refer to
	  external parameters, otherwise it will be treated unsupported
	*/
	bool exec_param_quals;

	/* Placeholder vars that assigned aliases */
	List *phv_alias;

	/* Vars that assigned aliases */
	List *var_alias;

	/* Print var with relname, i.e. t1.a */
	bool full_varname;

	/* Column name of excluded table in on conflict clause */
	List *excluded_table_columns;

	/* Print nextval with consumed sequence */
	bool consume_sequence;

	/* Do not print expr to mysql sql, just verify */
	bool noprint;
} RemotePrintExprContext;

extern void InitRemotePrintExprContext(RemotePrintExprContext *rpec, List*rtable);
extern void ResetRemotePrintExprContext(RemotePrintExprContext *rpec, bool b);
extern void print(const void *obj);
extern void pprint(const void *obj);
extern void elog_node_display(int lev, const char *title,
				  const void *obj, bool pretty);
extern char *format_node_dump(const char *dump);
extern char *pretty_format_node_dump(const char *dump);
extern void print_rt(const List *rtable);
extern void print_expr(const Node *expr, const List *rtable);
extern void print_pathkeys(const List *pathkeys, const List *rtable);
extern void print_tl(const List *tlist, const List *rtable);
extern void print_slot(TupleTableSlot *slot);

extern bool is_mysql_proc(Oid funcoid);
extern bool is_mysql_operator(Oid opoid);
extern bool is_expr_printable(const Expr *expr, RemotePrintExprContext *rpec);
extern int snprint_expr(StringInfo buf, const Expr *expr, RemotePrintExprContext *rpec);
extern Oid my_output_funcoid(Oid typid, bool *typIsVarlena);
#endif							/* PRINT_H */
